Skip to contents

Returns a data frame with the all officially reported changes to administrative identifiers, for the type and time period selected by the user.

The function calls the API of Statistics Norway (SSB) and returns the pre-processed information.

Usage

gather_change(type , from , to )

Arguments

type

A string: "kommune", "grunnkrets" or "fylket"

from

An integer: Start year of panel

to

An integer: End year of panel

Value

A 'data.frame' object, with five columns from, oldName, to, newName, year

  • from - originating numeric identifier

  • oldName - originating name of adm. unit

  • to - new numeric identifier

  • newName - new name of adm. unit

  • year - year, by which the change is enforced (01. January year)

Examples

expl <- gather_change(type = "kommune", from = 1999, to = 2018)
#> 
#> Information on Number and Type of Changes in Municipality Codes: 
#> 
#> There are a total of 85 in the time period: 1999 - 2018 
#> 
#> These are composed of: 
#> 
#> 	60 One-to-One Changes: 
#> 	25 Mergers 
#> 	0 Splits 
#> 	0 Split-Mergers
#>